@@ -2,12 +2,12 @@ package Tcl::pTk::DragDrop;
 require Tcl::pTk::DragDrop::Common;
 require Tcl::pTk::Toplevel;
 
-our ($VERSION) = ('0.94');
+our ($VERSION) = ('0.95');
 
 use base  qw(Tcl::pTk::DragDrop::Common Tcl::pTk::Toplevel);
 
 
-my $useWmRelease = 0; # We dont' ever use wmRelease
+my $useWmRelease = 0; # We don't ever use wmRelease
 
 Construct Tcl::pTk::Widget 'DragDrop';
 
